====
piel
====


.. image:: https://img.shields.io/pypi/v/piel.svg
        :target: https://pypi.python.org/pypi/piel

.. image:: https://img.shields.io/travis/daquintero/piel.svg
        :target: https://travis-ci.com/daquintero/piel

.. image:: https://readthedocs.org/projects/piel/badge/?version=latest
        :target: https://piel.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/daquintero/piel/shield.svg
     :target: https://pyup.io/repos/github/daquintero/piel/
     :alt: Updates



Photonic and electronic co-simulation system design tools interfaced with open-source design software like GDSFactory and OpenROAD.


* Free software: MIT license
* Documentation: https://piel.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
